@@ -56,9 +56,9 @@ public:
     virtual std::string TSUrl() const;
     virtual std::string verifyServiceUri() const;
 
-    virtual std::string PKCS12Cert() const;
-    virtual std::string PKCS12Pass() const;
-    virtual bool PKCS12Disable() const;
+    DIGIDOCPP_DEPRECATED virtual std::string PKCS12Cert() const;
+    DIGIDOCPP_DEPRECATED virtual std::string PKCS12Pass() const;
+    DIGIDOCPP_DEPRECATED virtual bool PKCS12Disable() const;
 
     virtual bool TSLAllowExpired() const;
     virtual bool TSLAutoUpdate() const;
@@ -113,6 +113,19 @@ private:
     DISABLE_COPY(ConfV4);
 };
 
-using ConfCurrent = ConfV4;
+class DIGIDOCPP_EXPORT ConfV5: public ConfV4
+{
+public:
+    ConfV5();
+    ~ConfV5() override;
+    static ConfV5* instance();
+
+    virtual std::vector<X509Cert> TSCerts() const;
+
+private:
+    DISABLE_COPY(ConfV5);
+};
+
+using ConfCurrent = ConfV5;
 #define CONF(method) (ConfCurrent::instance() ? ConfCurrent::instance()->method() : ConfCurrent().method())
 }
