@@ -50,9 +50,9 @@ public:
     std::string TSUrl() const override;
     std::string verifyServiceUri() const override;
 
-    std::string PKCS12Cert() const override;
-    std::string PKCS12Pass() const override;
-    bool PKCS12Disable() const override;
+    DIGIDOCPP_DEPRECATED std::string PKCS12Cert() const override;
+    DIGIDOCPP_DEPRECATED std::string PKCS12Pass() const override;
+    DIGIDOCPP_DEPRECATED bool PKCS12Disable() const override;
 
     bool TSLAutoUpdate() const override;
     std::string TSLCache() const override;
@@ -64,14 +64,15 @@ public:
     virtual void setProxyUser( const std::string &user );
     virtual void setProxyPass( const std::string &pass );
     virtual void setProxyTunnelSSL( bool enable );
-    virtual void setPKCS12Cert( const std::string &cert );
-    virtual void setPKCS12Pass( const std::string &pass );
-    virtual void setPKCS12Disable( bool disable );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Cert( const std::string &cert );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Pass( const std::string &pass );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Disable( bool disable );
 
     virtual void setTSLOnlineDigest( bool enable );
     virtual void setTSLTimeOut( int timeOut );
 
     virtual void setTSUrl(const std::string &url);
+    virtual void setVerifyServiceUri(const std::string &url);
 
 private:
     DISABLE_COPY(XmlConf);
@@ -81,6 +82,7 @@ private:
     friend class XmlConfV2;
     friend class XmlConfV3;
     friend class XmlConfV4;
+    friend class XmlConfV5;
 };
 
 class DIGIDOCPP_EXPORT XmlConfV2: public ConfV2
@@ -108,9 +110,9 @@ public:
     X509Cert verifyServiceCert() const override;
     std::string verifyServiceUri() const override;
 
-    std::string PKCS12Cert() const override;
-    std::string PKCS12Pass() const override;
-    bool PKCS12Disable() const override;
+    DIGIDOCPP_DEPRECATED std::string PKCS12Cert() const override;
+    DIGIDOCPP_DEPRECATED std::string PKCS12Pass() const override;
+    DIGIDOCPP_DEPRECATED bool PKCS12Disable() const override;
 
     bool TSLAutoUpdate() const override;
     std::string TSLCache() const override;
@@ -122,14 +124,15 @@ public:
     virtual void setProxyUser( const std::string &user );
     virtual void setProxyPass( const std::string &pass );
     virtual void setProxyTunnelSSL( bool enable );
-    virtual void setPKCS12Cert( const std::string &cert );
-    virtual void setPKCS12Pass( const std::string &pass );
-    virtual void setPKCS12Disable( bool disable );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Cert( const std::string &cert );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Pass( const std::string &pass );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Disable( bool disable );
 
     virtual void setTSLOnlineDigest( bool enable );
     virtual void setTSLTimeOut( int timeOut );
 
     virtual void setTSUrl(const std::string &url);
+    virtual void setVerifyServiceUri(const std::string &url);
 
 private:
     DISABLE_COPY(XmlConfV2);
@@ -163,9 +166,9 @@ public:
     X509Cert verifyServiceCert() const override;
     std::string verifyServiceUri() const override;
 
-    std::string PKCS12Cert() const override;
-    std::string PKCS12Pass() const override;
-    bool PKCS12Disable() const override;
+    DIGIDOCPP_DEPRECATED std::string PKCS12Cert() const override;
+    DIGIDOCPP_DEPRECATED std::string PKCS12Pass() const override;
+    DIGIDOCPP_DEPRECATED bool PKCS12Disable() const override;
 
     bool TSLAutoUpdate() const override;
     std::string TSLCache() const override;
@@ -177,14 +180,15 @@ public:
     virtual void setProxyUser( const std::string &user );
     virtual void setProxyPass( const std::string &pass );
     virtual void setProxyTunnelSSL( bool enable );
-    virtual void setPKCS12Cert( const std::string &cert );
-    virtual void setPKCS12Pass( const std::string &pass );
-    virtual void setPKCS12Disable( bool disable );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Cert( const std::string &cert );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Pass( const std::string &pass );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Disable( bool disable );
 
     virtual void setTSLOnlineDigest( bool enable );
     virtual void setTSLTimeOut( int timeOut );
 
     virtual void setTSUrl(const std::string &url);
+    virtual void setVerifyServiceUri(const std::string &url);
 
 private:
     DISABLE_COPY(XmlConfV3);
@@ -219,9 +223,9 @@ public:
     std::vector<X509Cert> verifyServiceCerts() const override;
     std::string verifyServiceUri() const override;
 
-    std::string PKCS12Cert() const override;
-    std::string PKCS12Pass() const override;
-    bool PKCS12Disable() const override;
+    DIGIDOCPP_DEPRECATED std::string PKCS12Cert() const override;
+    DIGIDOCPP_DEPRECATED std::string PKCS12Pass() const override;
+    DIGIDOCPP_DEPRECATED bool PKCS12Disable() const override;
 
     bool TSLAutoUpdate() const override;
     std::string TSLCache() const override;
@@ -233,14 +237,15 @@ public:
     virtual void setProxyUser( const std::string &user );
     virtual void setProxyPass( const std::string &pass );
     virtual void setProxyTunnelSSL( bool enable );
-    virtual void setPKCS12Cert( const std::string &cert );
-    virtual void setPKCS12Pass( const std::string &pass );
-    virtual void setPKCS12Disable( bool disable );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Cert( const std::string &cert );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Pass( const std::string &pass );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Disable( bool disable );
 
     virtual void setTSLOnlineDigest( bool enable );
     virtual void setTSLTimeOut( int timeOut );
 
     virtual void setTSUrl(const std::string &url);
+    virtual void setVerifyServiceUri(const std::string &url);
 
 private:
     DISABLE_COPY(XmlConfV4);
@@ -248,5 +253,63 @@ private:
     std::unique_ptr<XmlConf::Private> d;
 };
 
-using XmlConfCurrent = XmlConfV4;
+class DIGIDOCPP_EXPORT XmlConfV5: public ConfV5
+{
+public:
+    explicit XmlConfV5(const std::string &path = {}, const std::string &schema = {});
+    ~XmlConfV5() override;
+    static XmlConfV5* instance();
+
+    int logLevel() const override;
+    std::string logFile() const override;
+    std::string PKCS11Driver() const override;
+
+    std::string proxyHost() const override;
+    std::string proxyPort() const override;
+    std::string proxyUser() const override;
+    std::string proxyPass() const override;
+    bool proxyForceSSL() const override;
+    bool proxyTunnelSSL() const override;
+
+    std::string digestUri() const override;
+    std::string signatureDigestUri() const override;
+    std::string ocsp(const std::string &issuer) const override;
+    std::set<std::string> OCSPTMProfiles() const override;
+    std::vector<X509Cert> TSCerts() const override;
+    std::string TSUrl() const override;
+    X509Cert verifyServiceCert() const override;
+    std::vector<X509Cert> verifyServiceCerts() const override;
+    std::string verifyServiceUri() const override;
+
+    DIGIDOCPP_DEPRECATED std::string PKCS12Cert() const override;
+    DIGIDOCPP_DEPRECATED std::string PKCS12Pass() const override;
+    DIGIDOCPP_DEPRECATED bool PKCS12Disable() const override;
+
+    bool TSLAutoUpdate() const override;
+    std::string TSLCache() const override;
+    bool TSLOnlineDigest() const override;
+    int TSLTimeOut() const override;
+
+    virtual void setProxyHost( const std::string &host );
+    virtual void setProxyPort( const std::string &port );
+    virtual void setProxyUser( const std::string &user );
+    virtual void setProxyPass( const std::string &pass );
+    virtual void setProxyTunnelSSL( bool enable );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Cert( const std::string &cert );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Pass( const std::string &pass );
+    DIGIDOCPP_DEPRECATED virtual void setPKCS12Disable( bool disable );
+
+    virtual void setTSLOnlineDigest( bool enable );
+    virtual void setTSLTimeOut( int timeOut );
+
+    virtual void setTSUrl(const std::string &url);
+    virtual void setVerifyServiceUri(const std::string &url);
+
+private:
+    DISABLE_COPY(XmlConfV5);
+
+    std::unique_ptr<XmlConf::Private> d;
+};
+
+using XmlConfCurrent = XmlConfV5;
 }
